three_columns.pdf

## Metadata

Title | three_columns.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\three_columns.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403055447+01'00'
PDF Metadata: modDate | D:20230403055447+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h1 :: Est Quis quasi aut iure esse.
3. h6 :: Non voluptas dicta ut perspiciatis asperiores Ea
4. h6 :: Cum soluta iste ad nulla omnis.
5. h6 :: Sed dolorum rerum sit adipisci fugiat Est

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 176.89999389648438
y1 |  | 155.56900024414062
y0 |  | 75.14779663085938
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 187.36399841308594
y1 |  | 196.47357177734375
y0 |  | 170.54769897460938
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 200.01600646972656
y1 |  | 458.47772216796875
y0 |  | 198.14773559570312
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 182.4180145263672
y1 |  | 576.6917724609375
y0 |  | 475.86175537109375
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 197.6479949951172
y1 |  | 617.7535400390625
y0 |  | 591.8276977539062
x0 |  | 72.02400207519531

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 194.5279998779297
y1 |  | 645.353515625
y0 |  | 619.5535278320312
x0 |  | 72.02400207519531

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 197.63600158691406
y1 |  | 769.4476928710938
y0 |  | 647.0277099609375
x0 |  | 72.02400207519531

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 362.17401123046875
y1 |  | 154.70773315429688
y0 |  | 73.70773315429688
x0 |  | 234.2899932861328

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 354.7164001464844
y1 |  | 215.75857543945312
y0 |  | 171.23855590820312
x0 |  | 234.2899932861328

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 356.93798828125
y1 |  | 325.9835205078125
y0 |  | 231.05770874023438
x0 |  | 234.2899932861328

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 358.29400634765625
y1 |  | 367.383544921875
y0 |  | 327.7835388183594
x0 |  | 234.2899932861328

Path: | content.0.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 360.2179870605469
y1 |  | 519.0776977539062
y0 |  | 369.0577087402344
x0 |  | 234.2899932861328

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 361.30999755859375
y1 |  | 561.1444702148438
y0 |  | 535.3445434570312
x0 |  | 234.2899932861328

Path: | content.0.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 344.906005859375
y1 |  | 602.6945190429688
y0 |  | 576.4677124023438
x0 |  | 234.2899932861328

Path: | content.0.[14,14].bbox
Type: | addition

Key | Old | New
x1 |  | 361.17803955078125
y1 |  | 767.8876953125
y0 |  | 604.0676879882812
x0 |  | 234.2899932861328

Path: | content.0.[15,15].bbox
Type: | addition

Key | Old | New
x1 |  | 523.6900024414062
y1 |  | 209.90774536132812
y0 |  | 73.70773315429688
x0 |  | 396.42999267578125

Path: | content.0.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 519.1957397460938
y1 |  | 266.21002197265625
y0 |  | 226.22000122070312
x0 |  | 396.42999267578125

Path: | content.0.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 525.7059326171875
y1 |  | 391.8635559082031
y0 |  | 283.1377258300781
x0 |  | 396.42999267578125

Path: | content.0.[18,18].bbox
Type: | addition

Key | Old | New
x1 |  | 512.073974609375
y1 |  | 433.2835388183594
y0 |  | 393.68353271484375
x0 |  | 396.42999267578125

Path: | content.0.[19,19].bbox
Type: | addition

Key | Old | New
x1 |  | 516.64599609375
y1 |  | 502.58447265625
y0 |  | 434.9577331542969
x0 |  | 396.42999267578125

Path: | content.0.[20,20].bbox
Type: | addition

Key | Old | New
x1 |  | 520.0599975585938
y1 |  | 543.9844970703125
y0 |  | 504.3844909667969
x0 |  | 396.42999267578125

Path: | content.0.[21,21].bbox
Type: | addition

Key | Old | New
x1 |  | 528.0999755859375
y1 |  | 667.7877197265625
y0 |  | 545.357666015625
x0 |  | 396.42999267578125

Path: | content.0.[22,22].bbox
Type: | addition

Key | Old | New
x1 |  | 524.1400146484375
y1 |  | 764.647705078125
y0 |  | 683.627685546875
x0 |  | 396.42999267578125

# Est Quis quasi aut iure esse.

Lorem ipsum dolor sit amet. Et quam illo Quo

fugiat eum sint voluptates? Qui suscipit voluptatemEa architecto ut molestiae expedita est galisum laborum qui Quis necessitatibus ut impedit reprehenderit aut molestiae accusamus. Quo quia voluptate sit saepe sequisit eligendi et omnis nostrum et impedit dolores. Eum voluptates aperiam id voluptas assumendaet necessitatibus id sequi neque. Et voluptatem maxime est voluptatem quosest illum non vero laudantium?

Vel delectus officia ut consequuntur similique ut suscipit vero.

###### Non voluptas dicta ut perspiciatis asperiores Ea

dolore nam eaque praesentium. Aut ratione

ducimusIn voluptatibus quo autem iste quo enim facere est iste voluptas ea rerum assumenda sit repellat nihil. Ea dolor doloribus qui soluta iustoaut similique. Sit saepe rerum ut iusto maximeest dolor aut

pariatur molestiae. Eos delectus corporisUt perferendis et consectetur praesentium qui quia vero in itaque Quis ut illum numquam.

Ea excepturi eveniet qui alias rerum id facere error.

Qui eligendi eaque ex enim commodiea neque! Est magnam voluptas est tempora temporibusnon provident sit quae alias non veritatis laudantium. Non nesciunt earum Non

nulla eum impedit dolorum et esse maxime aut libero voluptatem hic

obcaecati optio a laboriosam sint. Aut cupiditate internos ea cumque praesentiumeum itaque qui sequi ipsa. Sit debitis voluptas33 quos ea nobis galisum. Et facere debitisquo velit est tempora voluptate. Sed quaerat exercitationemet tempore est fugit quia?

###### Cum soluta iste ad nulla omnis.

###### Sed dolorum rerum sit adipisci fugiat Est

obcaecati. Aut galisum architectoNon aperiam qui provident consequuntur qui nemo nihil in galisum dolore et fugiat explicabo! Aut neque amet qui nemo assumendaAut praesentium id voluptas ipsum qui illum ratione et molestiae laudantium 33 magni eligendi. Et

internos consequatur ut voluptatibus culpa33 repellat quo voluptatem quam rem cupiditate maiores. Aut illo quisquam et officia voluptatemEt autem et minus perferendis nam laudantium facere ut fugit similique?

Et fugiat sapiente aut sapiente suscipit aut rerum rerum.

Sit odit aliquam et molestiae praesentiumrem ducimus cum soluta soluta. At tempora saepe ut architecto temporaaut voluptate. Ex saepe mollitia eos voluptatem consequatur Aut

consequatur aut debitis sunt et atque rerum qui quasi totam. Ut nobis

minusEa earum qui quia vero est sint iste eum quam harum sed voluptate dicta. Ex enim quos At optio iure Sit

facere ut ratione praesentium aut pariatur reprehenderit.

Quo debitis maiores ut quis ducimusAut internos aut suscipit sapiente a maxime dicta ea dolorem illum vel illo mollitia. Est velit incidunt in nostrum nobisAb quisquam est iure fugit id velit quia sit atque nobis id itaque sunt.

Est velit nequeIn animi id temporibus atque est dolor debitis. Aut magnam dignissimos aut debitis aliquamA harum At nostrum deserunt nam

# Est Quis quasi aut iure esse.

Lorem ipsum dolor sit amet. Et quam illo Quo

fugiat eum sint voluptates? Qui suscipit voluptatemEa architecto ut molestiae expedita est galisum laborum qui Quis necessitatibus ut impedit reprehenderit aut molestiae accusamus. Quo quia voluptate sit saepe sequisit eligendi et omnis nostrum et impedit dolores. Eum voluptates aperiam id voluptas assumendaet necessitatibus id sequi neque. Et voluptatem maxime est voluptatem quosest illum non vero laudantium?

Vel delectus officia ut consequuntur similique ut suscipit vero.

###### Non voluptas dicta ut perspiciatis asperiores Ea

dolore nam eaque praesentium. Aut ratione

ducimusIn voluptatibus quo autem iste quo enim facere est iste voluptas ea rerum assumenda sit repellat nihil. Ea dolor doloribus qui soluta iustoaut similique. Sit saepe rerum ut iusto maximeest dolor aut

pariatur molestiae. Eos delectus corporisUt perferendis et consectetur praesentium qui quia vero in itaque Quis ut illum numquam.

Ea excepturi eveniet qui alias rerum id facere error.

Qui eligendi eaque ex enim commodiea neque! Est magnam voluptas est tempora temporibusnon provident sit quae alias non veritatis laudantium. Non nesciunt earum Non

nulla eum impedit dolorum et esse maxime aut libero voluptatem hic

obcaecati optio a laboriosam sint. Aut cupiditate internos ea cumque praesentiumeum itaque qui sequi ipsa. Sit debitis voluptas33 quos ea nobis galisum. Et facere debitisquo velit est tempora voluptate. Sed quaerat exercitationemet tempore est fugit quia?

###### Cum soluta iste ad nulla omnis.

###### Sed dolorum rerum sit adipisci fugiat Est

obcaecati. Aut galisum architectoNon aperiam qui provident consequuntur qui nemo nihil in galisum dolore et fugiat explicabo! Aut neque amet qui nemo assumendaAut praesentium id voluptas ipsum qui illum ratione et molestiae laudantium 33 magni eligendi. Et

internos consequatur ut voluptatibus culpa33 repellat quo voluptatem quam rem cupiditate maiores. Aut illo quisquam et officia voluptatemEt autem et minus perferendis nam laudantium facere ut fugit similique?

Et fugiat sapiente aut sapiente suscipit aut rerum rerum.

Sit odit aliquam et molestiae praesentiumrem ducimus cum soluta soluta. At tempora saepe ut architecto temporaaut voluptate. Ex saepe mollitia eos voluptatem consequatur Aut

consequatur aut debitis sunt et atque rerum qui quasi totam. Ut nobis

minusEa earum qui quia vero est sint iste eum quam harum sed voluptate dicta. Ex enim quos At optio iure Sit

facere ut ratione praesentium aut pariatur reprehenderit.

Quo debitis maiores ut quis ducimusAut internos aut suscipit sapiente a maxime dicta ea dolorem illum vel illo mollitia. Est velit incidunt in nostrum nobisAb quisquam est iure fugit id velit quia sit atque nobis id itaque sunt.

Est velit nequeIn animi id temporibus atque est dolor debitis. Aut magnam dignissimos aut debitis aliquamA harum At nostrum deserunt nam

Parent File Contents